@@ -375,6 +375,9 @@ STREAMS = {
                 'key_properties': ['sid'],
                 'replication_method': 'INCREMENTAL',
                 'replication_keys': ['event_date'],
+                'bookmark_query_field_from': 'StartDate',
+                'synch_since_bookmark': True,
+                'stringified_json_keys': ['worker_attributes', 'task_attributes'],
                 'params': {},
                 'pagination': 'meta',
             },
@@ -388,6 +391,7 @@ STREAMS = {
                 'key_properties': ['sid'],
                 'replication_method': 'INCREMENTAL',
                 'replication_keys': ['date_updated'],
+                'stringified_json_keys': ['attributes'],
                 'params': {},
                 'pagination': 'meta',
             },
@@ -468,6 +472,7 @@ STREAMS = {
                 'key_properties': ['sid'],
                 'replication_method': 'INCREMENTAL',
                 'replication_keys': ['date_updated'],
+                'stringified_json_keys': ['configuration'],
                 'params': {},
                 'pagination': 'meta',
             },
@@ -509,6 +514,7 @@ STREAMS = {
                 'key_properties': ['sid'],
                 'replication_method': 'INCREMENTAL',
                 'replication_keys': ['date_updated'],
+                'stringified_json_keys': ['attributes'],
                 'params': {},
                 'pagination': 'meta',
                 'children': {
